@@ -1,7 +1,8 @@
 from .fields import MsgFields as _MsgFields
 from .taskresults import TaskResults
-from .taskresult import TaskResult
+from .taskresult import TaskResult, TaskSeed
 
 MsgFields = _MsgFields()
 TaskResults = TaskResults
 TaskResult = TaskResult
+TaskResult = TaskSeed
