@@ -24,6 +24,12 @@ class ConstantDict(object):
         for value in self.dict().values():
             yield value
 
+    def __getattr__(self, name):
+        if name in self.dict():
+            return self._dict[name]
+        else:
+            return object.__getattribute__(self, name)
+
 
 class MsgFields(ConstantDict):
     ASNIP = "asnip"
@@ -38,3 +44,13 @@ class MsgFields(ConstantDict):
     SPIDER = "spider"
     URL = "url"
     WHOIS = "whois"
+    WHOIS_RAW = "raw"
+
+    META = "_"
+    META_START_TIME = "stime"
+    META_END_TIME = "etime"
+    META_SUCCESS = "ok"
+    META_RESULT = "r"
+    META_VERSION = "v"
+    META_ERR = "e"
+    META_MSG = "m"
